@@ -22,14 +22,13 @@ import (
 	"io"
 	"os"
 	"strings"
-	"time"
 
 	. "github.com/onsi/ginkgo"
 	. "github.com/onsi/gomega"
 	admregv1 "k8s.io/api/admissionregistration/v1"
 	appsv1 "k8s.io/api/apps/v1"
 	corev1 "k8s.io/api/core/v1"
-	extv1beta1 "k8s.io/apiextensions-apiserver/pkg/apis/apiextensions/v1beta1"
+	extv1 "k8s.io/apiextensions-apiserver/pkg/apis/apiextensions/v1"
 	apierrors "k8s.io/apimachinery/pkg/api/errors"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	v1 "k8s.io/apimachinery/pkg/apis/meta/v1"
@@ -45,12 +44,6 @@ import (
 )
 
 const (
-	// The length of time between polls.
-	pollInterval = 1 * time.Second
-	// How long to try before giving up.
-	waitTimeout = 1 * time.Minute
-	// Longer try before giving up.
-	longWaitTimeout = waitTimeout * 4
 	// Gatekeeper name and namespace
 	gkName                      = "gatekeeper"
 	gatekeeperWithAllValuesFile = "gatekeeper_with_all_values.yaml"
@@ -59,7 +52,6 @@ const (
 var (
 	ctx                   = context.Background()
 	globalsInitialized    = false
-	gkNamespace           = ""
 	auditName             = types.NamespacedName{}
 	controllerManagerName = types.NamespacedName{}
 	gatekeeperName        = types.NamespacedName{
@@ -70,21 +62,20 @@ var (
 )
 
 func initializeGlobals() {
-	gkNamespace = *GatekeeperNamespace
 	auditName = types.NamespacedName{
-		Namespace: gkNamespace,
+		Namespace: gatekeeperNamespace,
 		Name:      "gatekeeper-audit",
 	}
 	controllerManagerName = types.NamespacedName{
-		Namespace: gkNamespace,
+		Namespace: gatekeeperNamespace,
 		Name:      "gatekeeper-controller-manager",
 	}
 	validatingWebhookName = types.NamespacedName{
-		Namespace: gkNamespace,
+		Namespace: gatekeeperNamespace,
 		Name:      "gatekeeper-validating-webhook-configuration",
 	}
 	mutatingWebhookName = types.NamespacedName{
-		Namespace: gkNamespace,
+		Namespace: gatekeeperNamespace,
 		Name:      "gatekeeper-mutating-webhook-configuration",
 	}
 }
@@ -112,58 +103,18 @@ var _ = Describe("Gatekeeper", func() {
 				return false
 			}
 			return apierrors.IsNotFound(err)
-		}, longWaitTimeout, pollInterval).Should(BeTrue())
-	})
-
-	Describe("Install", func() {
-		Context("Creating Gatekeeper custom resource", func() {
-			It("Should install Gatekeeper", func() {
-				gatekeeper := &v1alpha1.Gatekeeper{}
-				gatekeeper.Namespace = gkNamespace
-				err := loadGatekeeperFromFile(gatekeeper, "operator_v1alpha1_gatekeeper.yaml")
-				Expect(err).ToNot(HaveOccurred())
-				gkDeployment := &appsv1.Deployment{}
-
-				By("Creating Gatekeeper resource", func() {
-					Expect(K8sClient.Create(ctx, gatekeeper)).Should(Succeed())
-				})
-
-				By("Creating an affinity pod for testing gatekeeper affinity settings", func() {
-					affinityPod, err := loadAffinityPodFromFile(gkNamespace)
-					Expect(err).ToNot(HaveOccurred())
-					Expect(K8sClient.Create(ctx, affinityPod)).Should(Succeed())
-				})
-
-				By("Checking gatekeeper-controller-manager readiness", func() {
-					Eventually(func() (int32, error) {
-						return getDeploymentReadyReplicas(ctx, controllerManagerName, gkDeployment)
-					}, waitTimeout, pollInterval).Should(Equal(*gatekeeper.Spec.Webhook.Replicas))
-				})
-
-				By("Checking gatekeeper-audit readiness", func() {
-					Eventually(func() (int32, error) {
-						return getDeploymentReadyReplicas(ctx, auditName, gkDeployment)
-					}, waitTimeout, pollInterval).Should(Equal(*gatekeeper.Spec.Audit.Replicas))
-				})
-
-				By("Checking validatingWebhookConfiguration is deployed", func() {
-					validatingWebhookConfiguration := &admregv1.ValidatingWebhookConfiguration{}
-					Eventually(func() error {
-						return K8sClient.Get(ctx, validatingWebhookName, validatingWebhookConfiguration)
-					}, waitTimeout, pollInterval).ShouldNot(HaveOccurred())
-					Expect(validatingWebhookConfiguration.OwnerReferences).To(HaveLen(1))
-					Expect(validatingWebhookConfiguration.OwnerReferences[0].Kind).To(Equal("Gatekeeper"))
-					Expect(validatingWebhookConfiguration.OwnerReferences[0].Name).To(Equal(gkName))
-				})
-
-			})
-		})
+		}, deleteTimeout, pollInterval).Should(BeTrue())
 	})
 
 	Describe("Overriding CR", func() {
 		It("Creating an empty gatekeeper contains default values", func() {
 			gatekeeper := emptyGatekeeper()
-			Expect(K8sClient.Create(ctx, gatekeeper)).Should(Succeed())
+			err := loadGatekeeperFromFile(gatekeeper, "gatekeeper_empty.yaml")
+			Expect(err).ToNot(HaveOccurred())
+
+			By("Creating Gatekeeper resource", func() {
+				Expect(K8sClient.Create(ctx, gatekeeper)).Should(Succeed())
+			})
 
 			auditDeployment, webhookDeployment := gatekeeperDeployments()
 
@@ -174,6 +125,30 @@ var _ = Describe("Gatekeeper", func() {
 				Expect(*webhookDeployment.Spec.Replicas).To(Equal(test.DefaultDeployment.WebhookReplicas))
 			})
 
+			By("Checking gatekeeper-controller-manager readiness", func() {
+				gkDeployment := &appsv1.Deployment{}
+				Eventually(func() (int32, error) {
+					return getDeploymentReadyReplicas(ctx, controllerManagerName, gkDeployment)
+				}, timeout, pollInterval).Should(Equal(test.DefaultDeployment.WebhookReplicas))
+			})
+
+			By("Checking gatekeeper-audit readiness", func() {
+				gkDeployment := &appsv1.Deployment{}
+				Eventually(func() (int32, error) {
+					return getDeploymentReadyReplicas(ctx, auditName, gkDeployment)
+				}, timeout, pollInterval).Should(Equal(test.DefaultDeployment.AuditReplicas))
+			})
+
+			By("Checking validatingWebhookConfiguration is deployed", func() {
+				validatingWebhookConfiguration := &admregv1.ValidatingWebhookConfiguration{}
+				Eventually(func() error {
+					return K8sClient.Get(ctx, validatingWebhookName, validatingWebhookConfiguration)
+				}, timeout, pollInterval).ShouldNot(HaveOccurred())
+				Expect(validatingWebhookConfiguration.OwnerReferences).To(HaveLen(1))
+				Expect(validatingWebhookConfiguration.OwnerReferences[0].Kind).To(Equal("Gatekeeper"))
+				Expect(validatingWebhookConfiguration.OwnerReferences[0].Name).To(Equal(gkName))
+			})
+
 			By("Checking default pod affinity", func() {
 				Expect(auditDeployment.Spec.Template.Spec.Affinity).To(BeNil())
 				Expect(webhookDeployment.Spec.Template.Spec.Affinity).To(BeEquivalentTo(test.DefaultDeployment.Affinity))
@@ -260,12 +235,17 @@ var _ = Describe("Gatekeeper", func() {
 				Expect(found).To(BeFalse())
 			})
 
-			byCheckingMutationDisabled(webhookDeployment)
+			By("Checking default disabled builtins", func() {
+				_, found := getContainerArg(webhookDeployment.Spec.Template.Spec.Containers[0].Args, controllers.DisabledBuiltinArg)
+				Expect(found).To(BeFalse())
+			})
+
+			byCheckingMutationDisabled(auditDeployment, webhookDeployment)
 		})
 
 		It("Contains the configured values", func() {
 			gatekeeper := &v1alpha1.Gatekeeper{}
-			gatekeeper.Namespace = gkNamespace
+			gatekeeper.Namespace = gatekeeperNamespace
 			err := loadGatekeeperFromFile(gatekeeper, gatekeeperWithAllValuesFile)
 			Expect(err).ToNot(HaveOccurred())
 			Expect(K8sClient.Create(ctx, gatekeeper)).Should(Succeed())
@@ -275,6 +255,10 @@ var _ = Describe("Gatekeeper", func() {
 				Expect(auditDeployment.Spec.Replicas).NotTo(BeNil())
 				Expect(auditDeployment.Spec.Replicas).To(Equal(gatekeeper.Spec.Audit.Replicas))
 				Expect(webhookDeployment.Spec.Replicas).NotTo(BeNil())
+				// TODO: Remove once flake has been fixed. See
+				// https://github.com/gatekeeper/gatekeeper-operator/pull/168/checks?check_run_id=2918723659
+				// for example failure.
+				fmt.Fprint(GinkgoWriter, "webhookDeployment", webhookDeployment)
 				Expect(webhookDeployment.Spec.Replicas).To(Equal(gatekeeper.Spec.Webhook.Replicas))
 			})
 
@@ -304,9 +288,9 @@ var _ = Describe("Gatekeeper", func() {
 			})
 
 			By("Checking expected image", func() {
-				Expect(auditDeployment.Spec.Template.Spec.Containers[0].Image).To(Equal(*gatekeeper.Spec.Image.Image))
+				Expect(auditDeployment.Spec.Template.Spec.Containers[0].Image).ToNot(Equal(*gatekeeper.Spec.Image.Image))
 				Expect(auditDeployment.Spec.Template.Spec.Containers[0].ImagePullPolicy).To(Equal(*gatekeeper.Spec.Image.ImagePullPolicy))
-				Expect(webhookDeployment.Spec.Template.Spec.Containers[0].Image).To(Equal(*gatekeeper.Spec.Image.Image))
+				Expect(webhookDeployment.Spec.Template.Spec.Containers[0].Image).ToNot(Equal(*gatekeeper.Spec.Image.Image))
 				Expect(webhookDeployment.Spec.Template.Spec.Containers[0].ImagePullPolicy).To(Equal(*gatekeeper.Spec.Image.ImagePullPolicy))
 			})
 
@@ -314,7 +298,7 @@ var _ = Describe("Gatekeeper", func() {
 				gkDeployment := &appsv1.Deployment{}
 				Eventually(func() (int32, error) {
 					return getDeploymentReadyReplicas(ctx, controllerManagerName, gkDeployment)
-				}, longWaitTimeout, pollInterval).Should(Equal(*gatekeeper.Spec.Webhook.Replicas))
+				}, timeout, pollInterval).Should(Equal(*gatekeeper.Spec.Webhook.Replicas))
 			})
 
 			By("Checking webhook is available", func() {
@@ -378,6 +362,12 @@ var _ = Describe("Gatekeeper", func() {
 				Expect(found).To(BeTrue())
 				Expect(value).To(Equal(util.ToArg(controllers.LogLevelArg, "ERROR")))
 			})
+
+			By("Checking expected disabled builtins", func() {
+				value, found := getContainerArg(webhookDeployment.Spec.Template.Spec.Containers[0].Args, controllers.DisabledBuiltinArg)
+				Expect(found).To(BeTrue())
+				Expect(value).To(Equal(util.ToArg(controllers.DisabledBuiltinArg, "http.send")))
+			})
 		})
 
 		It("Does not deploy the ValidatingWebhookConfiguration", func() {
@@ -409,9 +399,9 @@ var _ = Describe("Gatekeeper", func() {
 			webhookMode := v1alpha1.WebhookEnabled
 			gatekeeper.Spec.MutatingWebhook = &webhookMode
 			Expect(K8sClient.Create(ctx, gatekeeper)).Should(Succeed())
-			_, webhookDeployment := gatekeeperDeployments()
+			auditDeployment, webhookDeployment := gatekeeperDeployments()
 
-			byCheckingMutationEnabled(webhookDeployment)
+			byCheckingMutationEnabled(auditDeployment, webhookDeployment)
 
 			byCheckingFailurePolicy(&mutatingWebhookName, "default",
 				util.MutatingWebhookConfigurationKind,
@@ -421,7 +411,7 @@ var _ = Describe("Gatekeeper", func() {
 			byCheckingNamespaceSelector(&mutatingWebhookName, "default",
 				util.MutatingWebhookConfigurationKind,
 				controllers.MutationGatekeeperWebhook,
-				nil)
+				test.DefaultDeployment.NamespaceSelector)
 		})
 
 		It("Enables Gatekeeper mutation with configured values", func() {
@@ -431,9 +421,9 @@ var _ = Describe("Gatekeeper", func() {
 			webhookMode := v1alpha1.WebhookEnabled
 			gatekeeper.Spec.MutatingWebhook = &webhookMode
 			Expect(K8sClient.Create(ctx, gatekeeper)).Should(Succeed())
-			_, webhookDeployment := gatekeeperDeployments()
+			auditDeployment, webhookDeployment := gatekeeperDeployments()
 
-			byCheckingMutationEnabled(webhookDeployment)
+			byCheckingMutationEnabled(auditDeployment, webhookDeployment)
 
 			byCheckingFailurePolicy(&mutatingWebhookName, "expected",
 				util.MutatingWebhookConfigurationKind,
@@ -454,8 +444,8 @@ var _ = Describe("Gatekeeper", func() {
 				Expect(K8sClient.Create(ctx, gatekeeper)).Should(Succeed())
 			})
 
-			_, webhookDeployment := gatekeeperDeployments()
-			byCheckingMutationEnabled(webhookDeployment)
+			auditDeployment, webhookDeployment := gatekeeperDeployments()
+			byCheckingMutationEnabled(auditDeployment, webhookDeployment)
 
 			By("Getting Gatekeeper CR for updating", func() {
 				err := K8sClient.Get(ctx, gatekeeperName, gatekeeper)
@@ -468,19 +458,21 @@ var _ = Describe("Gatekeeper", func() {
 				Expect(K8sClient.Update(ctx, gatekeeper)).Should(Succeed())
 			})
 
-			_, webhookDeployment = gatekeeperDeployments()
-			byCheckingMutationDisabled(webhookDeployment)
+			auditDeployment, webhookDeployment = gatekeeperDeployments()
+			byCheckingMutationDisabled(auditDeployment, webhookDeployment)
 		})
 	})
 })
 
 func gatekeeperDeployments() (auditDeployment, webhookDeployment *appsv1.Deployment) {
+	return gatekeeperAuditDeployment(), gatekeeperWebhookDeployment()
+}
+
+func gatekeeperAuditDeployment() (auditDeployment *appsv1.Deployment) {
 	auditDeployment = &appsv1.Deployment{}
 	Eventually(func() error {
 		return K8sClient.Get(ctx, auditName, auditDeployment)
-	}, waitTimeout, pollInterval).ShouldNot(HaveOccurred())
-
-	webhookDeployment = gatekeeperWebhookDeployment()
+	}, timeout, pollInterval).ShouldNot(HaveOccurred())
 	return
 }
 
@@ -488,7 +480,7 @@ func gatekeeperWebhookDeployment() (webhookDeployment *appsv1.Deployment) {
 	webhookDeployment = &appsv1.Deployment{}
 	Eventually(func() error {
 		return K8sClient.Get(ctx, controllerManagerName, webhookDeployment)
-	}, waitTimeout, pollInterval).ShouldNot(HaveOccurred())
+	}, timeout, pollInterval).ShouldNot(HaveOccurred())
 	return
 }
 
@@ -504,30 +496,39 @@ func byCheckingValidationEnabled() {
 		validatingWebhookConfiguration := &admregv1.ValidatingWebhookConfiguration{}
 		Eventually(func() error {
 			return K8sClient.Get(ctx, validatingWebhookName, validatingWebhookConfiguration)
-		}, waitTimeout, pollInterval).ShouldNot(HaveOccurred())
+		}, timeout, pollInterval).ShouldNot(HaveOccurred())
 	})
 }
 
-type getCRDFunc func(types.NamespacedName, *extv1beta1.CustomResourceDefinition)
+type getCRDFunc func(types.NamespacedName, *extv1.CustomResourceDefinition)
 
-func byCheckingMutationEnabled(webhookDeployment *appsv1.Deployment) {
+func byCheckingMutationEnabled(auditDeployment, webhookDeployment *appsv1.Deployment) {
 	By(fmt.Sprintf("Checking %s argument is set", controllers.EnableMutationArg), func() {
-		_, found := getContainerArg(webhookDeployment.Spec.Template.Spec.Containers[0].Args, controllers.EnableMutationArg)
-		Expect(found).To(BeTrue())
+		Eventually(func() bool {
+			_, found := getContainerArg(webhookDeployment.Spec.Template.Spec.Containers[0].Args, controllers.EnableMutationArg)
+			return found
+		}, timeout, pollInterval).Should(BeTrue())
+	})
+
+	By(fmt.Sprintf("Checking %s=%s argument is set", controllers.OperationArg, controllers.OperationMutationStatus), func() {
+		Eventually(func() bool {
+			return findContainerArgValue(auditDeployment.Spec.Template.Spec.Containers[0].Args,
+				controllers.OperationArg, controllers.OperationMutationStatus)
+		}, timeout, pollInterval).Should(BeTrue())
 	})
 
 	By("Checking MutatingWebhookConfiguration deployed", func() {
 		mutatingWebhookConfiguration := &admregv1.MutatingWebhookConfiguration{}
 		Eventually(func() error {
 			return K8sClient.Get(ctx, mutatingWebhookName, mutatingWebhookConfiguration)
-		}, waitTimeout, pollInterval).ShouldNot(HaveOccurred())
+		}, timeout, pollInterval).ShouldNot(HaveOccurred())
 	})
 
 	var crdFn getCRDFunc
-	crdFn = func(crdName types.NamespacedName, mutatingCRD *extv1beta1.CustomResourceDefinition) {
+	crdFn = func(crdName types.NamespacedName, mutatingCRD *extv1.CustomResourceDefinition) {
 		Eventually(func() error {
 			return K8sClient.Get(ctx, crdName, mutatingCRD)
-		}, waitTimeout, pollInterval).ShouldNot(HaveOccurred())
+		}, timeout, pollInterval).ShouldNot(HaveOccurred())
 	}
 	byCheckingMutatingCRDs("deployed", crdFn)
 }
@@ -538,17 +539,26 @@ func byCheckingValidationDisabled() {
 		Eventually(func() bool {
 			err := K8sClient.Get(ctx, validatingWebhookName, validatingWebhookConfiguration)
 			return apierrors.IsNotFound(err)
-		}, waitTimeout, pollInterval).Should(BeTrue())
+		}, timeout, pollInterval).Should(BeTrue())
 	})
 }
 
-func byCheckingMutationDisabled(webhookDeployment *appsv1.Deployment) {
+func byCheckingMutationDisabled(auditDeployment, webhookDeployment *appsv1.Deployment) {
 	By(fmt.Sprintf("Checking %s argument is not set", controllers.EnableMutationArg), func() {
 		Eventually(func() bool {
 			webhookDeployment = gatekeeperWebhookDeployment()
 			_, found := getContainerArg(webhookDeployment.Spec.Template.Spec.Containers[0].Args, controllers.EnableMutationArg)
 			return found
-		}, waitTimeout, pollInterval).Should(BeFalse())
+		}, timeout, pollInterval).Should(BeFalse())
+	})
+
+	By(fmt.Sprintf("Checking %s=%s argument is not set", controllers.OperationArg, controllers.OperationMutationStatus), func() {
+		Eventually(func() bool {
+			auditDeployment = gatekeeperAuditDeployment()
+			found := findContainerArgValue(auditDeployment.Spec.Template.Spec.Containers[0].Args,
+				controllers.OperationArg, controllers.OperationMutationStatus)
+			return found
+		}, timeout, pollInterval).Should(BeFalse())
 	})
 
 	By("Checking MutatingWebhookConfiguration not deployed", func() {
@@ -556,40 +566,29 @@ func byCheckingMutationDisabled(webhookDeployment *appsv1.Deployment) {
 		Eventually(func() bool {
 			err := K8sClient.Get(ctx, mutatingWebhookName, mutatingWebhookConfiguration)
 			return apierrors.IsNotFound(err)
-		}, waitTimeout, pollInterval).Should(BeTrue())
+		}, timeout, pollInterval).Should(BeTrue())
 	})
 
 	var crdFn getCRDFunc
-	crdFn = func(crdName types.NamespacedName, mutatingCRD *extv1beta1.CustomResourceDefinition) {
+	crdFn = func(crdName types.NamespacedName, mutatingCRD *extv1.CustomResourceDefinition) {
 		Eventually(func() bool {
 			err := K8sClient.Get(ctx, crdName, mutatingCRD)
 			return apierrors.IsNotFound(err)
-		}, waitTimeout, pollInterval).Should(BeTrue())
+		}, timeout, pollInterval).Should(BeTrue())
 	}
 	byCheckingMutatingCRDs("not deployed", crdFn)
 }
 
 func byCheckingMutatingCRDs(deployMsg string, f getCRDFunc) {
-	mutatingCRDs := []struct {
-		kind string
-		name string
-	}{
-		{
-			"Assign",
-			"assign.mutations.gatekeeper.sh",
-		},
-		{
-			"AssignMetadata",
-			"assignmetadata.mutations.gatekeeper.sh",
-		},
-	}
+	for _, asset := range controllers.MutatingCRDs {
+		obj, err := util.GetManifestObject(asset)
+		Expect(err).ToNot(HaveOccurred())
 
-	for _, crd := range mutatingCRDs {
 		crdNamespacedName := types.NamespacedName{
-			Name: crd.name,
+			Name: obj.GetName(),
 		}
-		By(fmt.Sprintf("Checking %s Mutating CRD %s", crd.kind, deployMsg), func() {
-			mutatingAssignCRD := &extv1beta1.CustomResourceDefinition{}
+		By(fmt.Sprintf("Checking %s Mutating CRD %s", obj.GetName(), deployMsg), func() {
+			mutatingAssignCRD := &extv1.CustomResourceDefinition{}
 			f(crdNamespacedName, mutatingAssignCRD)
 		})
 	}
@@ -603,7 +602,7 @@ func byCheckingFailurePolicy(webhookNamespacedName *types.NamespacedName,
 		webhookConfiguration.SetKind(kind)
 		Eventually(func() error {
 			return K8sClient.Get(ctx, *webhookNamespacedName, webhookConfiguration)
-		}, waitTimeout, pollInterval).ShouldNot(HaveOccurred())
+		}, timeout, pollInterval).ShouldNot(HaveOccurred())
 		assertFailurePolicy(webhookConfiguration, webhookName, failurePolicy)
 	})
 }
@@ -622,7 +621,7 @@ func byCheckingNamespaceSelector(webhookNamespacedName *types.NamespacedName,
 		webhookConfiguration.SetKind(kind)
 		Eventually(func() error {
 			return K8sClient.Get(ctx, *webhookNamespacedName, webhookConfiguration)
-		}, waitTimeout, pollInterval).ShouldNot(HaveOccurred())
+		}, timeout, pollInterval).ShouldNot(HaveOccurred())
 		assertNamespaceSelector(webhookConfiguration, webhookName, namespaceSelector)
 	})
 }
@@ -685,6 +684,16 @@ func getContainerArg(args []string, argPrefix string) (arg string, found bool) {
 	return "", false
 }
 
+func findContainerArgValue(args []string, argKey, argValue string) bool {
+	argKeyValue := fmt.Sprintf("%s=%s", argKey, argValue)
+	for _, arg := range args {
+		if strings.Compare(arg, argKeyValue) == 0 {
+			return true
+		}
+	}
+	return false
+}
+
 func loadGatekeeperFromFile(gatekeeper *v1alpha1.Gatekeeper, fileName string) error {
 	f, err := os.Open(fmt.Sprintf("../../config/samples/%s", fileName))
 	if err != nil {
@@ -721,7 +730,7 @@ func emptyGatekeeper() *v1alpha1.Gatekeeper {
 	return &v1alpha1.Gatekeeper{
 		ObjectMeta: v1.ObjectMeta{
 			Name:      gkName,
-			Namespace: gkNamespace,
+			Namespace: gatekeeperNamespace,
 		},
 	}
 }
@@ -754,15 +763,3 @@ func getDefaultImage(file string) (image string, imagePullPolicy corev1.PullPoli
 	}
 	return image, corev1.PullPolicy(policy), nil
 }
-
-func loadAffinityPodFromFile(namespace string) (*corev1.Pod, error) {
-	f, err := os.Open("../../config/samples/affinity_pod.yaml")
-	if err != nil {
-		return nil, err
-	}
-	defer f.Close()
-	pod := &corev1.Pod{}
-	err = decodeYAML(f, pod)
-	pod.ObjectMeta.Namespace = namespace
-	return pod, err
-}
