@@ -18,8 +18,19 @@ package e2e
 
 import (
 	"flag"
+	"time"
 
 	"github.com/gatekeeper/gatekeeper-operator/pkg/util"
 )
 
-var GatekeeperNamespace = flag.String("namespace", util.DefaultGatekeeperNamespace, "The namespace to run tests")
+var gatekeeperNamespace string
+var pollInterval time.Duration
+var timeout time.Duration
+var deleteTimeout time.Duration
+
+func init() {
+	flag.StringVar(&gatekeeperNamespace, "namespace", util.DefaultGatekeeperNamespace, "The namespace to run tests")
+	flag.DurationVar(&pollInterval, "poll-interval", 1*time.Second, "The length of time between polls")
+	flag.DurationVar(&timeout, "timeout", 1*time.Minute, "The length of time to poll before giving up")
+	flag.DurationVar(&deleteTimeout, "delete-timeout", 5*time.Minute, "The length of time to wait for deletion of all resources")
+}
